@@ -15,11 +15,11 @@
 	minimized=invisible,
 	invisible=FALSE,
 	split=grid,
-	N=paste('Run',run,if(split)c('c','e') else NULL,sep=''),
+	N=glue('Run',run,if(split)c('c','e') else NULL),
 	o=rdir,
 	e=rdir,
 	L=if(split)c(compileflag(compiler(config(dirname(command)))),NA)else NA,
-	hold_jid=if(split)c(NA,paste('Run',run,'c',sep=''))else NA,
+	hold_jid=if(split)c(NA,glue('Run',run,'c'))else NA,
 	V='',
 	j='y',
 	q=if(split)
@@ -72,7 +72,7 @@ qsub <- function(
 	)
 	args <- list(...)
 	args <- args[names(args) %in% range]
-	if(length(args))names(args) <- paste(sep='','-',names(args))	
+	if(length(args))names(args) <- glue('-',names(args))	
 	vectors <- c(as.list(names(args)),args)
 	vectors <- vectors[t(matrix(seq(length.out=length(vectors)),ncol=2))]
 	string <- do.call(paste,vectors)
@@ -82,7 +82,6 @@ qsub <- function(
 }
 config <- function(dir,...)file.path(dir,'config.xml')
 compiler <- function(config,pathsep='/',...){
-	library(XML)
 	tree <- xmlParse(config)
 	nmtran <- xmlValue(getNodeSet(tree,"//d:instruction[@id='nmtran']/text()",c(d='http://metruminstitute.org/nmqual/configuration'))[[1]])
 	nmtran <- sub('^ *','',nmtran)
@@ -90,7 +89,6 @@ compiler <- function(config,pathsep='/',...){
 	rev(strsplit(comp,pathsep)[[1]])[[1]]
 }
 nmVersion <- function(config,...){
-	library(XML)
 	tree <- xmlParse(config)
 	as.numeric(getNodeSet(tree,"//d:nonmem/@version",c(d='http://metruminstitute.org/nmqual/configuration'))[[1]])
 }
